@@ -18,20 +18,20 @@
 
 #pragma once
 
-#include <qlat-utils/show.h>
 #include <qlat-utils/assert.h>
-
+#include <qlat-utils/show.h>
 #include <sys/time.h>
+
 #include <algorithm>
+#include <cmath>
 #include <cstdarg>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
-#include <cmath>
-#include <string>
-#include <vector>
 #include <map>
 #include <set>
+#include <string>
+#include <vector>
 
 #ifdef USE_PAPI
 #include <papi.h>
@@ -41,14 +41,6 @@
 #include <omp.h>
 #endif
 
-// #if defined USE_MPI || defined USE_QMP
-// #define USE_MULTI_NODE
-// #endif
-// 
-// #ifdef USE_MULTI_NODE
-// #include <mpi.h>
-// #endif
-
 #define TIMER(FNAME)                 \
   static std::string fname = FNAME;  \
   static qlat::Timer timer(fname, true); \
@@ -253,7 +245,7 @@ inline long get_env_long_default(const std::string& var_name, const long x0)
 
 inline long get_verbose_level()
 {
-  const long x0 = -1; // default verbose_level
+  const long x0 = -1;  // default verbose_level
   const std::string var_name = "q_verbose";
   const std::string val = get_env(var_name);
   long x;
@@ -262,9 +254,6 @@ inline long get_verbose_level()
   } else {
     x = read_long(val);
   }
-  if (x >= 0) {
-    displayln_info(ssprintf("%s=%ld", var_name.c_str(), x));
-  }
   return x;
 }
 
