@@ -3,7 +3,7 @@ import sys
 flags = sys.getdlopenflags()
 sys.setdlopenflags(flags | ctypes.RTLD_GLOBAL)
 
-from cqlat_utils import *
 from .cp import *
+from .cpa import *
 
 sys.setdlopenflags(flags)
