@@ -9,6 +9,7 @@ from qlat_utils.c import qar_create
 from qlat_utils.c import qar_extract
 from qlat_utils.c import qcopy_file
 from qlat_utils.c import list_qar
+from qlat_utils.c import qar_build_index
 
 from qlat_utils.timer import *
 
@@ -36,6 +37,14 @@ def qcat_bytes_sync_node(path):
         return c.qcat_bytes_sync_node(path)
     return qcat_bytes(path)
 
+@timer
+def qar_build_index_info(path_qar):
+    """
+    create "path_qar.idx" file
+    """
+    if get_id_node() == 0:
+        qar_build_index(path_qar)
+
 @timer
 def qar_create_info(path_qar, path_folder, *, is_remove_folder_after = False):
     if get_num_node() != 1:
